# Smart Paste

**AI-powered form filling for Drupal 11** - Automatically extracts and
populates form fields from unstructured clipboard data.

Smart Paste is a Drupal 11 module that enables AI-powered intelligent form
filling. It allows users to copy unstructured data (from emails, messages,
etc.) and automatically populate Drupal forms using artificial intelligence.

## Features

- **AI-Powered Data Extraction**: Uses AI models to extract structured data
  from unstructured text
- **Automatic Form Population**: Intelligently fills form fields based on
  extracted data
- **Multiple AI Provider Support**: Integrates with the AI module to support
  various providers (OpenAI, Mistral, Bedrock, Ollama, etc.)
- **Configurable Form Targeting**: Choose which forms should have Smart Paste
  buttons
- **Modern JavaScript**: Uses vanilla JavaScript with Drupal behaviors for
  optimal performance
- **Secure**: Implements proper CSRF protection and permission checks

## Requirements

- Drupal 11.0 or higher
- [AI module](https://www.drupal.org/project/ai) - provides AI provider abstraction
- [Key module](https://www.drupal.org/project/key) - for secure API key storage
- At least one AI provider module (e.g., OpenAI, Gemini, etc.)

## Installation

1. Download and extract the module to your `modules/contrib` directory
2. Enable the module: `drush en smart_paste`
3. Configure the module at `/admin/config/services/smart-paste`

## Configuration

### Basic Setup

1. **Enable Smart Paste**: Check the "Enable Smart Paste" option
2. **AI Provider**: Select your preferred AI provider from the dropdown
3. **AI Model**: Choose the specific model to use for data extraction
4. **Form Targeting**: Choose which forms should have Smart Paste buttons

### Form Targeting Options

- **All forms (except excluded)**: Adds Smart Paste to all forms except
  those in the exclusion list
- **Only specific forms**: Only adds Smart Paste to forms explicitly listed
  in the allowed forms field

### Default Excluded Forms

The following forms are excluded by default for security and usability
reasons:
- Login forms (`user_login_form`)
- Password reset forms (`user_pass`)
- Search forms (`search_block_form`, `search_form`)
- Views exposed filter forms (`views_exposed_form`)
- Views bulk operation forms (`views_bulk_operations_form`, `views_form`)
- Admin toolbar forms (patterns: `/^admin_toolbar_/`)
- System module management forms

**Note**: Search and filter forms are automatically excluded as Smart Paste
is not useful for these types of forms.

## How It Works

1. **User Copies Data**: User copies unstructured text (email, message, etc.)
   to clipboard
2. **Click Smart Paste**: User clicks the Smart Paste button (available in
   the form actions area or "more actions" menu, depending on the admin
   theme) on any enabled form
3. **Form Analysis**: JavaScript analyzes the form structure and field types
4. **AI Processing**: Unstructured data and form structure are sent to the
   AI provider
5. **Data Extraction**: AI extracts relevant information and returns
   structured JSON
6. **Form Population**: JavaScript populates form fields with the extracted
   data

**Note**: The Smart Paste button only appears on forms that have a
Save/Submit button. In admin themes like Gin, it may appear in the "more
actions" dropdown menu for better UI organization.

## Supported Field Types

- Text inputs (text, email, tel, url)
- Textareas
- Text format fields (formatted text with HTML)
- Select dropdowns
- Radio buttons
- Checkboxes

## Permissions

- **Administer Smart Paste** (`administer smart paste`): Configure module
  settings
- **Use Smart Paste** (`use smart paste`): Use Smart Paste functionality on
  forms

## Security Considerations

- All API requests include CSRF tokens
- User permissions are checked before processing
- Sensitive forms are excluded by default
- No data is stored permanently on the server

## Troubleshooting

### Smart Paste Button Not Appearing

- Verify the module is enabled
- Check that Smart Paste is enabled in configuration
- Ensure the current user has "use smart paste" permission
- Verify the form is not in the excluded forms list
- **Ensure the form has a Save/Submit button** (Smart Paste only appears on
  forms with Save buttons)
- **Check the "more actions" menu**: In admin themes like Gin, the Smart
  Paste button may appear in the "more actions" dropdown menu rather than
  directly beside the Save button

### AI Processing Errors

- Check that the AI provider is properly configured
- Verify API keys are set correctly in the AI module
- Check the Drupal logs for detailed error messages
- Ensure the selected AI model supports chat/text operations

### Form Fields Not Filling

- Check browser console for JavaScript errors
- Verify the clipboard contains text data
- Ensure form fields have proper `name` attributes
- Check that field types are supported

## Development

### Extending Smart Paste

The module provides several services that can be extended:

- `smart_paste.service`: Core Smart Paste functionality
- `smart_paste.controller`: AJAX endpoint handling

### Custom Field Type Support

To add support for custom field types, modify the JavaScript
`fillFormFields` function in `js/smart-paste.js`.

### Custom AI Prompts

The AI prompt generation can be customized by extending the
`SmartPasteService::generatePrompt()` method.
