<?php

namespace Drupal\smart_paste\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Simple test form to verify Smart Paste button visibility.
 */
class SmartPasteTestForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'smart_paste_test_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#suffix'] = '<div class="smart-paste-test-suffix">
      <p>Title: Text to test the Smart Paste button</p>
      <p>To test the Smart Paste functionality, copy this text to your clipboard and then click the Smart Paste button.</p>
      <pre>
  Breite Straße 8, 30159 Hannover, Germany
  test@test.com
  +49 123 444555

  Category: Technology
  Subscribe to Newsletter: true

  HTML Content: <h2>Welcome to our Service</h2><p>This is a <strong>sample HTML content</strong> with <em>formatting</em> and a <a href="https://example.com">link</a>.</p><ul><li>Feature 1</li><li>Feature 2</li></ul></pre>
      </pre>
    </div>';

    $form['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#description' => $this->t('Enter a title. Smart Paste can auto-fill title from clipboard.'),
      '#required' => TRUE,
    ];

    $form['description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Description'),
      '#description' => $this->t('Enter a description. Smart Paste can populate the description from clipboard.'),
      '#rows' => 4,
    ];

    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('E-Mail'),
      '#description' => $this->t('Enter an email address. Smart Paste can auto-detect emails.'),
    ];

    $form['phone'] = [
      '#type' => 'tel',
      '#title' => $this->t('Phone'),
      '#description' => $this->t('Enter a phone number. Smart Paste can auto-detect phone numbers.'),
    ];

    $form['address'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Address'),
      '#description' => $this->t('Enter an address. Smart Paste can extract address information.'),
    ];

    $form['html_content'] = [
      '#type' => 'text_format',
      '#title' => $this->t('HTML Content'),
      '#description' => $this->t('Enter HTML content. Smart Paste can process rich text and HTML from clipboard.'),
      '#format' => 'basic_html',
      '#rows' => 6,
    ];

    $form['category'] = [
      '#type' => 'select',
      '#title' => $this->t('Category'),
      '#description' => $this->t('Select a category. Smart Paste can suggest appropriate categories.'),
      '#options' => [
        '' => $this->t('- Select -'),
        'personal' => $this->t('Personal'),
        'business' => $this->t('Business'),
        'education' => $this->t('Education'),
        'healthcare' => $this->t('Healthcare'),
        'technology' => $this->t('Technology'),
        'other' => $this->t('Other'),
      ],
    ];

    $form['newsletter'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Subscribe to Newsletter'),
      '#description' => $this->t('Check to subscribe to newsletter. Smart Paste can detect subscription preferences.'),
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    $form['actions']['cancel'] = [
      '#type' => 'submit',
      '#value' => $this->t('Cancel'),
      '#submit' => ['::cancelSubmit'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (empty($form_state->getValue('title'))) {
      $form_state->setErrorByName('title', $this->t('Title is required.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $message_parts = [
      'Title: ' . $values['title'],
      'Email: ' . ($values['email'] ?: 'Not provided'),
      'Phone: ' . ($values['phone'] ?: 'Not provided'),
      'Address: ' . ($values['address'] ?: 'Not provided'),
      'HTML Content: ' . (!empty($values['html_content']['value']) ? 'Provided (' . strlen($values['html_content']['value']) . ' characters)' : 'Not provided'),
      'Category: ' . ($values['category'] ?: 'Not selected'),
      'Newsletter: ' . ($values['newsletter'] ? 'Yes' : 'No'),
    ];

    $this->messenger()->addMessage($this->t('Test form submitted successfully!<br>@data', [
      '@data' => implode('<br>', $message_parts),
    ]));
  }

  /**
   * Cancel form submission.
   */
  public function cancelSubmit(array &$form, FormStateInterface $form_state) {
    $this->messenger()->addMessage($this->t('Form submission cancelled.'));
  }

}
